@@ -13,7 +13,6 @@ mod memory_interop;
 mod transform_executor;
 
 // entrypoint fn swc calls to perform its transform via plugin.
-#[cfg(not(target_arch = "wasm32"))]
 pub fn apply_transform_plugin(
     plugin_name: &str,
     path: &Path,
@@ -35,8 +34,3 @@ pub fn apply_transform_plugin(
         )
     })
 }
-
-#[cfg(target_arch = "wasm32")]
-pub fn apply_transform_plugin() -> Result<Serialized, Error> {
-    unimplemented!("Not implemented yet");
-}
